==> eisp-mdm-2.3.3-RELEASE-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTerminalDao_findTmTerminalByAllPossible.sql <==
SELECT 
	tt.id,
	tt.terminal_code,
	tt.terminal_name,
	tt.erp_code,
	tt.terminal_type,
	tt.channel_type,
	tt.org_id,
	tt.address,
	tt.linkman,
	tt.linkman_phone,
	tt.cooperative,
	tt.province,
	tt.city,
	tt.area,
	tt.enable_status,
	tt.create_date,
	tt.create_name,
	tt.update_date,
	tt.update_name,
	tt.ext_char_1 AS extChar1,
	tt.ext_char_2 AS extChar2,
	tt.ext_char_3 AS extChar3,
	tt.ext_char_4 AS extChar4,
	tt.ext_char_5 AS extChar5,
	tt.ext_char_6 AS extChar6,
	tt.ext_char_7 AS extChar7,
	tt.ext_char_8 AS extChar8,
	tt.ext_char_9 AS extChar9,
	tt.ext_char_10 AS extChar10,
	tt.ext_char_11 AS extChar11,
	tt.ext_char_12 AS extChar12,
	tt.ext_char_13 AS extChar13,
	tt.ext_char_14 AS extChar14,
	tt.ext_char_15 AS extChar15,
	tt.ext_char_16 AS extChar16,
	tt.ext_char_17 AS extChar17,
	tt.ext_char_18 AS extChar18,
	tt.ext_char_19 AS extChar19,
	tt.ext_char_20 AS extChar20,
	tt.ext_char_21 AS extChar21,
	tt.ext_char_22 AS extChar22,
	tt.ext_char_23 AS extChar23,
	tt.ext_char_24 AS extChar24,
	tt.ext_char_25 AS extChar25,
	tt.ext_char_26 AS extChar26,
	tt.ext_char_27 AS extChar27,
	tt.ext_char_28 AS extChar28,
	tt.ext_char_29 AS extChar29,
	tt.ext_char_30 AS extChar30,
	tt.ext_number_1 AS extNumber1,
	tt.ext_number_2 AS extNumber2,
	tt.ext_number_3 AS extNumber3,
	tt.ext_number_4 AS extNumber4,
	tt.ext_number_5 AS extNumber5
FROM TM_TERMINAL TT WHERE TT.ENABLE_STATUS=0
<#if queryTmTerminalVo.id ?exists&&queryTmTerminalVo.id ?length gt 0>
	AND TT.ID = '${queryTmTerminalVo.id}'
</#if> 
<#if queryTmTerminalVo.terminalCode ?exists&&queryTmTerminalVo.terminalCode ?length gt 0>
	AND TT.TERMINAL_CODE LIKE '%${queryTmTerminalVo.terminalCode}%'
</#if> 
<#if queryTmTerminalVo.terminalName ?exists&&queryTmTerminalVo.terminalName ?length gt 0>
	AND TT.TERMINAL_NAME LIKE '%${queryTmTerminalVo.terminalName}%'
</#if> 
<#if queryTmTerminalVo.terminalType ?exists&&queryTmTerminalVo.terminalType ?length gt 0>
	AND TT.TERMINAL_TYPE = '${queryTmTerminalVo.terminalType}'
</#if> 
<#if queryTmTerminalVo.cooperative ?exists&&queryTmTerminalVo.cooperative ?length gt 0>
	AND TT.COOPERATIVE = '${queryTmTerminalVo.cooperative}'
</#if> 
<#if queryTmTerminalVo.notInIds ?exists&&queryTmTerminalVo.notInIds ?length gt 0>
	AND TT.ID NOT IN(${queryTmTerminalVo.notInIds})
</#if> 
<#if queryTmTerminalVo.positionId ?exists&&queryTmTerminalVo.positionId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TTCP ON TTCP.TERMINAL_ID=TT.ID
		WHERE TTCP.POSITION_ID='${queryTmTerminalVo.positionId}'
	)
</#if> 
<#if queryTmTerminalVo.positionName ?exists&&queryTmTerminalVo.positionName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TTCP ON TTCP.TERMINAL_ID=TT.ID
		JOIN TM_POSITION TP ON TP.ID=TTCP.POSITION_ID
		WHERE TP.POSITION_NAME LIKE '%${queryTmTerminalVo.positionName}%'
	)
</#if> 
<#if queryTmTerminalVo.levelAllPositionId ?exists&&queryTmTerminalVo.levelAllPositionId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TTCP ON TTCP.TERMINAL_ID=TT.ID
		JOIN TM_POSITION TP ON TP.ID=TTCP.POSITION_ID
		START WITH TP.ID='${queryTmTerminalVo.levelAllPositionId}' CONNECT BY PRIOR TP.ID=TP.PARENT_ID
	)
</#if> 
<#if queryTmTerminalVo.orgId ?exists&&queryTmTerminalVo.orgId ?length gt 0>
	AND TT.ORG_ID = '${queryTmTerminalVo.orgId}'
</#if> 
<#if queryTmTerminalVo.orgName ?exists&&queryTmTerminalVo.orgName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_ORG TG ON TT.ORG_ID=TG.ID
		WHERE TG.ORG_NAME LIKE '%${queryTmTerminalVo.orgName}%'
	)
</#if> 
<#if queryTmTerminalVo.levelAllOrgId ?exists&&queryTmTerminalVo.levelAllOrgId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_ORG TG ON TT.ORG_ID=TG.ID
		START WITH TG.ID='${queryTmTerminalVo.levelAllOrgId}' CONNECT BY PRIOR TG.ID=TG.PARENT_ID
	)
</#if> 
<#if queryTmTerminalVo.customerId ?exists&&queryTmTerminalVo.customerId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		WHERE TRCP.CUSTOMER_ID ='${queryTmTerminalVo.customerId}'
	)
</#if> 
<#if queryTmTerminalVo.customerName ?exists&&queryTmTerminalVo.customerName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		WHERE TC.CUSTOMER_NAME LIKE '%${queryTmTerminalVo.customerName}%'
	)
</#if> 
<#if queryTmTerminalVo.customeCode ?exists&&queryTmTerminalVo.customeCode ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		WHERE TC.CUSTOMER_CODE LIKE '%${queryTmTerminalVo.customeCode}%'
	)
</#if> 
<#if queryTmTerminalVo.userId ?exists&&queryTmTerminalVo.userId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT 
		LEFT JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		LEFT JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		LEFT JOIN TM_R_USER_CUSTOMER TRUP ON TRUP.CUSTOMER_ID=TC.ID
		LEFT JOIN TM_USER TU ON TU.ID=TRUP.USER_ID
		WHERE TU.ID = '${queryTmTerminalVo.userId}'
	)
</#if> 
<#if queryTmTerminalVo.fullName ?exists&&queryTmTerminalVo.fullName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT 
		LEFT JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		LEFT JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		LEFT JOIN TM_R_USER_CUSTOMER TRUP ON TRUP.CUSTOMER_ID=TC.ID
		LEFT JOIN TM_USER TU ON TU.ID=TRUP.USER_ID
		WHERE TU.FULLNAME LIKE '%${queryTmTerminalVo.fullName}%'
	)
</#if>

==> eisp-mdm-2.5.7-RELEASE-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTerminalDao_findTmTerminalByAllPossible.sql <==
SELECT 
	tt.id,
	tt.terminal_code,
	tt.terminal_name,
	tt.erp_code,
	tt.terminal_type,
	tt.channel_type,
	tt.org_id,
	tt.address,
	tt.linkman,
	tt.linkman_phone,
	tt.cooperative,
	tt.province,
	tt.city,
	tt.area,
	tt.enable_status,
	tt.create_date,
	tt.create_name,
	tt.update_date,
	tt.update_name,
	tt.ext_char_1 AS extChar1,
	tt.ext_char_2 AS extChar2,
	tt.ext_char_3 AS extChar3,
	tt.ext_char_4 AS extChar4,
	tt.ext_char_5 AS extChar5,
	tt.ext_char_6 AS extChar6,
	tt.ext_char_7 AS extChar7,
	tt.ext_char_8 AS extChar8,
	tt.ext_char_9 AS extChar9,
	tt.ext_char_10 AS extChar10,
	tt.ext_char_11 AS extChar11,
	tt.ext_char_12 AS extChar12,
	tt.ext_char_13 AS extChar13,
	tt.ext_char_14 AS extChar14,
	tt.ext_char_15 AS extChar15,
	tt.ext_char_16 AS extChar16,
	tt.ext_char_17 AS extChar17,
	tt.ext_char_18 AS extChar18,
	tt.ext_char_19 AS extChar19,
	tt.ext_char_20 AS extChar20,
	tt.ext_char_21 AS extChar21,
	tt.ext_char_22 AS extChar22,
	tt.ext_char_23 AS extChar23,
	tt.ext_char_24 AS extChar24,
	tt.ext_char_25 AS extChar25,
	tt.ext_char_26 AS extChar26,
	tt.ext_char_27 AS extChar27,
	tt.ext_char_28 AS extChar28,
	tt.ext_char_29 AS extChar29,
	tt.ext_char_30 AS extChar30,
	tt.ext_number_1 AS extNumber1,
	tt.ext_number_2 AS extNumber2,
	tt.ext_number_3 AS extNumber3,
	tt.ext_number_4 AS extNumber4,
	tt.ext_number_5 AS extNumber5,
	tt.bpm_status as bpmStatus
FROM TM_TERMINAL TT WHERE TT.ENABLE_STATUS=0
<#if queryTmTerminalVo.id ?exists&&queryTmTerminalVo.id ?length gt 0>
	AND TT.ID = '${queryTmTerminalVo.id}'
</#if> 
<#if queryTmTerminalVo.terminalCode ?exists&&queryTmTerminalVo.terminalCode ?length gt 0>
	AND TT.TERMINAL_CODE LIKE '%${queryTmTerminalVo.terminalCode}%'
</#if> 
<#if queryTmTerminalVo.terminalName ?exists&&queryTmTerminalVo.terminalName ?length gt 0>
	AND TT.TERMINAL_NAME LIKE '%${queryTmTerminalVo.terminalName}%'
</#if> 
<#if queryTmTerminalVo.terminalType ?exists&&queryTmTerminalVo.terminalType ?length gt 0>
	AND TT.TERMINAL_TYPE = '${queryTmTerminalVo.terminalType}'
</#if> 
<#if queryTmTerminalVo.cooperative ?exists&&queryTmTerminalVo.cooperative ?length gt 0>
	AND TT.COOPERATIVE = '${queryTmTerminalVo.cooperative}'
</#if> 
<#if queryTmTerminalVo.notInIds ?exists&&queryTmTerminalVo.notInIds ?length gt 0>
	AND TT.ID NOT IN(${queryTmTerminalVo.notInIds})
</#if> 
<#if queryTmTerminalVo.positionId ?exists&&queryTmTerminalVo.positionId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TTCP ON TTCP.TERMINAL_ID=TT.ID
		WHERE TTCP.POSITION_ID='${queryTmTerminalVo.positionId}'
	)
</#if> 
<#if queryTmTerminalVo.positionName ?exists&&queryTmTerminalVo.positionName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TTCP ON TTCP.TERMINAL_ID=TT.ID
		JOIN TM_POSITION TP ON TP.ID=TTCP.POSITION_ID
		WHERE TP.POSITION_NAME LIKE '%${queryTmTerminalVo.positionName}%'
	)
</#if> 
<#if queryTmTerminalVo.levelAllPositionId ?exists&&queryTmTerminalVo.levelAllPositionId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TTCP ON TTCP.TERMINAL_ID=TT.ID
		JOIN TM_POSITION TP ON TP.ID=TTCP.POSITION_ID
		START WITH TP.ID='${queryTmTerminalVo.levelAllPositionId}' CONNECT BY PRIOR TP.ID=TP.PARENT_ID
	)
</#if> 
<#if queryTmTerminalVo.orgId ?exists&&queryTmTerminalVo.orgId ?length gt 0>
	AND TT.ORG_ID = '${queryTmTerminalVo.orgId}'
</#if> 
<#if queryTmTerminalVo.orgName ?exists&&queryTmTerminalVo.orgName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_ORG TG ON TT.ORG_ID=TG.ID
		WHERE TG.ORG_NAME LIKE '%${queryTmTerminalVo.orgName}%'
	)
</#if> 
<#if queryTmTerminalVo.levelAllOrgId ?exists&&queryTmTerminalVo.levelAllOrgId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_ORG TG ON TT.ORG_ID=TG.ID
		START WITH TG.ID='${queryTmTerminalVo.levelAllOrgId}' CONNECT BY PRIOR TG.ID=TG.PARENT_ID
	)
</#if> 
<#if queryTmTerminalVo.customerId ?exists&&queryTmTerminalVo.customerId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		WHERE TRCP.CUSTOMER_ID ='${queryTmTerminalVo.customerId}'
	)
</#if> 
<#if queryTmTerminalVo.customerName ?exists&&queryTmTerminalVo.customerName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		WHERE TC.CUSTOMER_NAME LIKE '%${queryTmTerminalVo.customerName}%'
	)
</#if> 
<#if queryTmTerminalVo.customeCode ?exists&&queryTmTerminalVo.customeCode ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT
		JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		WHERE TC.CUSTOMER_CODE LIKE '%${queryTmTerminalVo.customeCode}%'
	)
</#if> 
<#if queryTmTerminalVo.userId ?exists&&queryTmTerminalVo.userId ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT 
		LEFT JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		LEFT JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		LEFT JOIN TM_R_USER_CUSTOMER TRUP ON TRUP.CUSTOMER_ID=TC.ID
		LEFT JOIN TM_USER TU ON TU.ID=TRUP.USER_ID
		WHERE TU.ID = '${queryTmTerminalVo.userId}'
	)
</#if> 
<#if queryTmTerminalVo.fullName ?exists&&queryTmTerminalVo.fullName ?length gt 0>
	AND TT.ID IN (
		SELECT TT.ID FROM TM_TERMINAL TT 
		LEFT JOIN TM_R_TERM_CUST_POS_BG TRCP ON TT.ID=TRCP.TERMINAL_ID
		LEFT JOIN TM_CUSTOMER TC ON TC.ID=TRCP.CUSTOMER_ID
		LEFT JOIN TM_R_USER_CUSTOMER TRUP ON TRUP.CUSTOMER_ID=TC.ID
		LEFT JOIN TM_USER TU ON TU.ID=TRUP.USER_ID
		WHERE TU.FULLNAME LIKE '%${queryTmTerminalVo.fullName}%'
	)
</#if>
